[m-dev.] diff: more MR_ prefixes

Zoltan Somogyi zs at cs.mu.OZ.AU
Sat Jan 13 20:45:47 AEDT 2001


Add a lot of MR_ prefixes.

compiler/llds_out.m:
	Add MR_ prefixes to the labels do_succeed, do_last_succeed,
	do_redo, do_fail and do_not_reached.

library/exception.m:
library/private_builtin.m:
library/std_util.m:
runtime/mercury_engine.c:
runtime/mercury_ho_call.c:
runtime/mercury_regs.c:
trace/mercury_trace.c:
	Add MR_ prefixes to register references.

runtime/mercury_tabling.c:
	Add MR_ prefixes to register references and to C module dividers.

runtime/mercury_prof.c:
	Fix an incorrect MR_ prefix.

Zoltan.

cvs diff: Diffing .
cvs diff: Diffing bindist
cvs diff: Diffing boehm_gc
cvs diff: Diffing boehm_gc/Mac_files
cvs diff: Diffing boehm_gc/cord
cvs diff: Diffing boehm_gc/cord/private
cvs diff: Diffing boehm_gc/include
cvs diff: Diffing boehm_gc/include/private
cvs diff: Diffing browser
cvs diff: Diffing bytecode
cvs diff: Diffing compiler
Index: compiler/llds_out.m
===================================================================
RCS file: /home/mercury1/repository/mercury/compiler/llds_out.m,v
retrieving revision 1.168
diff -u -b -r1.168 llds_out.m
--- compiler/llds_out.m	2000/12/04 18:28:18	1.168
+++ compiler/llds_out.m	2001/01/12 15:03:52
@@ -3280,15 +3280,15 @@
 output_code_addr(do_succeed(Last)) -->
 	(
 		{ Last = no },
-		io__write_string("MR_ENTRY(do_succeed)")
+		io__write_string("MR_ENTRY(MR_do_succeed)")
 	;
 		{ Last = yes },
-		io__write_string("MR_ENTRY(do_last_succeed)")
+		io__write_string("MR_ENTRY(MR_do_last_succeed)")
 	).
 output_code_addr(do_redo) -->
-	io__write_string("MR_ENTRY(do_redo)").
+	io__write_string("MR_ENTRY(MR_do_redo)").
 output_code_addr(do_fail) -->
-	io__write_string("MR_ENTRY(do_fail)").
+	io__write_string("MR_ENTRY(MR_do_fail)").
 output_code_addr(do_trace_redo_fail_shallow) -->
 	io__write_string("MR_ENTRY(MR_do_trace_redo_fail_shallow)").
 output_code_addr(do_trace_redo_fail_deep) -->
@@ -3314,7 +3314,7 @@
 output_code_addr(do_aditi_bulk_modify) -->
 	io__write_string("MR_ENTRY(do_aditi_bulk_modify)").
 output_code_addr(do_not_reached) -->
-	io__write_string("MR_ENTRY(do_not_reached)").
+	io__write_string("MR_ENTRY(MR_do_not_reached)").
 
 	% The code should be kept in sync with output_data_addr/2 below.
 llds_out__make_stack_layout_name(Label, Name) :-
cvs diff: Diffing compiler/notes
cvs diff: Diffing debian
cvs diff: Diffing doc
cvs diff: Diffing extras
cvs diff: Diffing extras/aditi
cvs diff: Diffing extras/cgi
cvs diff: Diffing extras/complex_numbers
cvs diff: Diffing extras/complex_numbers/samples
cvs diff: Diffing extras/complex_numbers/tests
cvs diff: Diffing extras/concurrency
cvs diff: Diffing extras/curses
cvs diff: Diffing extras/curses/sample
cvs diff: Diffing extras/dynamic_linking
cvs diff: Diffing extras/graphics
cvs diff: Diffing extras/graphics/mercury_opengl
cvs diff: Diffing extras/graphics/mercury_tcltk
cvs diff: Diffing extras/graphics/samples
cvs diff: Diffing extras/graphics/samples/calc
cvs diff: Diffing extras/graphics/samples/maze
cvs diff: Diffing extras/graphics/samples/pent
cvs diff: Diffing extras/lazy_evaluation
cvs diff: Diffing extras/logged_output
cvs diff: Diffing extras/moose
cvs diff: Diffing extras/moose/samples
cvs diff: Diffing extras/morphine
cvs diff: Diffing extras/morphine/non-regression-tests
cvs diff: Diffing extras/morphine/scripts
cvs diff: Diffing extras/morphine/source
cvs diff: Diffing extras/odbc
cvs diff: Diffing extras/posix
cvs diff: Diffing extras/references
cvs diff: Diffing extras/references/samples
cvs diff: Diffing extras/references/tests
cvs diff: Diffing extras/stream
cvs diff: Diffing extras/trailed_update
cvs diff: Diffing extras/trailed_update/samples
cvs diff: Diffing extras/trailed_update/tests
cvs diff: Diffing extras/xml
cvs diff: Diffing extras/xml/samples
cvs diff: Diffing library
Index: library/private_builtin.m
===================================================================
RCS file: /home/mercury1/repository/mercury/library/private_builtin.m,v
retrieving revision 1.64
diff -u -b -r1.64 private_builtin.m
--- library/private_builtin.m	2001/01/09 23:30:17	1.64
+++ library/private_builtin.m	2001/01/13 07:21:41
@@ -386,9 +386,9 @@
 	int	comp;
 
 	MR_save_transient_registers();
-	comp = MR_compare_type_info((MR_TypeInfo) r1, (MR_TypeInfo) r2);
+	comp = MR_compare_type_info((MR_TypeInfo) MR_r1, (MR_TypeInfo) MR_r2);
 	MR_restore_transient_registers();
-	r1 = (comp == MR_COMPARE_EQUAL);
+	MR_r1 = (comp == MR_COMPARE_EQUAL);
 	MR_proceed();
 }
 
@@ -403,9 +403,9 @@
 	int	comp;
 
 	MR_save_transient_registers();
-	comp = MR_compare_type_info((MR_TypeInfo) r1, (MR_TypeInfo) r2);
+	comp = MR_compare_type_info((MR_TypeInfo) MR_r1, (MR_TypeInfo) MR_r2);
 	MR_restore_transient_registers();
-	r1 = comp;
+	MR_r1 = comp;
 	MR_proceed();
 }
 
Index: library/std_util.m
===================================================================
RCS file: /home/mercury1/repository/mercury/library/std_util.m,v
retrieving revision 1.217
diff -u -b -r1.217 std_util.m
--- library/std_util.m	2001/01/09 23:30:18	1.217
+++ library/std_util.m	2001/01/13 08:56:29
@@ -1255,9 +1255,9 @@
 	int	comp;
 
 	MR_save_transient_registers();
-	comp = MR_compare_type_info((MR_TypeInfo) r1, (MR_TypeInfo) r2);
+	comp = MR_compare_type_info((MR_TypeInfo) MR_r1, (MR_TypeInfo) MR_r2);
 	MR_restore_transient_registers();
-	r1 = (comp == MR_COMPARE_EQUAL);
+	MR_r1 = (comp == MR_COMPARE_EQUAL);
 	MR_proceed();
 }
 
@@ -1269,9 +1269,9 @@
 	int	comp;
 
 	MR_save_transient_registers();
-	comp = MR_compare_type_info((MR_TypeInfo) r1, (MR_TypeInfo) r2);
+	comp = MR_compare_type_info((MR_TypeInfo) MR_r1, (MR_TypeInfo) MR_r2);
 	MR_restore_transient_registers();
-	r1 = comp;
+	MR_r1 = comp;
 	MR_proceed();
 }
 
cvs diff: Diffing profiler
cvs diff: Diffing robdd
cvs diff: Diffing runtime
Index: runtime/mercury_engine.c
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_engine.c,v
retrieving revision 1.32
diff -u -b -r1.32 mercury_engine.c
--- runtime/mercury_engine.c	2001/01/11 07:55:35	1.32
+++ runtime/mercury_engine.c	2001/01/13 07:21:42
@@ -163,7 +163,7 @@
 **	The called routine should be det/semidet/cc_multi/cc_nondet.
 **
 **	If the called routine returns normally (this includes the case of a
-**	semidet/cc_nondet routine failing, i.e. returning with r1 = FALSE),
+**	semidet/cc_nondet routine failing, i.e. returning with MR_r1 = FALSE),
 **	then MR_call_engine() will return NULL.
 **
 **	If the called routine exits by throwing an exception, then the
Index: runtime/mercury_prof.h
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_prof.h,v
retrieving revision 1.12
diff -u -b -r1.12 mercury_prof.h
--- runtime/mercury_prof.h	2000/12/04 18:35:08	1.12
+++ runtime/mercury_prof.h	2001/01/12 15:05:41
@@ -42,7 +42,7 @@
 
 /*
 ** This variable holds the address of the calling procedure
-** for a call to MR_do_call_closure or MR_do_call_class_method.
+** for a call to mercury__do_call_closure or mercury__do_call_class_method.
 */
 
 #ifdef PROFILE_CALLS
Index: runtime/mercury_regs.c
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_regs.c,v
retrieving revision 1.4
diff -u -b -r1.4 mercury_regs.c
--- runtime/mercury_regs.c	2000/11/23 02:00:37	1.4
+++ runtime/mercury_regs.c	2001/01/12 14:17:19
@@ -15,38 +15,38 @@
 	MR_restore_transient_registers();
  	switch (num) {
 
-	case 1:  return r1;
-	case 2:  return r2;
-	case 3:  return r3;
-	case 4:  return r4;
-	case 5:  return r5;
-	case 6:  return r6;
-	case 7:  return r7;
-	case 8:  return r8;
-	case 9:  return r9;
-	case 10: return r10;
-	case 11: return r11;
-	case 12: return r12;
-	case 13: return r13;
-	case 14: return r14;
-	case 15: return r15;
-	case 16: return r16;
-	case 17: return r17;
-	case 18: return r18;
-	case 19: return r19;
-	case 20: return r20;
-	case 21: return r21;
-	case 22: return r22;
-	case 23: return r23;
-	case 24: return r24;
-	case 25: return r25;
-	case 26: return r26;
-	case 27: return r27;
-	case 28: return r28;
-	case 29: return r29;
-	case 30: return r30;
-	case 31: return r31;
-	case 32: return r32;
+	case 1:  return MR_r1;
+	case 2:  return MR_r2;
+	case 3:  return MR_r3;
+	case 4:  return MR_r4;
+	case 5:  return MR_r5;
+	case 6:  return MR_r6;
+	case 7:  return MR_r7;
+	case 8:  return MR_r8;
+	case 9:  return MR_r9;
+	case 10: return MR_r10;
+	case 11: return MR_r11;
+	case 12: return MR_r12;
+	case 13: return MR_r13;
+	case 14: return MR_r14;
+	case 15: return MR_r15;
+	case 16: return MR_r16;
+	case 17: return MR_r17;
+	case 18: return MR_r18;
+	case 19: return MR_r19;
+	case 20: return MR_r20;
+	case 21: return MR_r21;
+	case 22: return MR_r22;
+	case 23: return MR_r23;
+	case 24: return MR_r24;
+	case 25: return MR_r25;
+	case 26: return MR_r26;
+	case 27: return MR_r27;
+	case 28: return MR_r28;
+	case 29: return MR_r29;
+	case 30: return MR_r30;
+	case 31: return MR_r31;
+	case 32: return MR_r32;
 
 	}
 
@@ -62,38 +62,38 @@
 	MR_restore_transient_registers();
  	switch (num) {
 
-	case 1:  r1  = val; MR_save_transient_registers(); return val;
-	case 2:  r2  = val; MR_save_transient_registers(); return val;
-	case 3:  r3  = val; MR_save_transient_registers(); return val;
-	case 4:  r4  = val; MR_save_transient_registers(); return val;
-	case 5:  r5  = val; MR_save_transient_registers(); return val;
-	case 6:  r6  = val; MR_save_transient_registers(); return val;
-	case 7:  r7  = val; MR_save_transient_registers(); return val;
-	case 8:  r8  = val; MR_save_transient_registers(); return val;
-	case 9:  r9  = val; MR_save_transient_registers(); return val;
-	case 10: r10 = val; MR_save_transient_registers(); return val;
-	case 11: r11 = val; MR_save_transient_registers(); return val;
-	case 12: r12 = val; MR_save_transient_registers(); return val;
-	case 13: r13 = val; MR_save_transient_registers(); return val;
-	case 14: r14 = val; MR_save_transient_registers(); return val;
-	case 15: r15 = val; MR_save_transient_registers(); return val;
-	case 16: r16 = val; MR_save_transient_registers(); return val;
-	case 17: r17 = val; MR_save_transient_registers(); return val;
-	case 18: r18 = val; MR_save_transient_registers(); return val;
-	case 19: r19 = val; MR_save_transient_registers(); return val;
-	case 20: r20 = val; MR_save_transient_registers(); return val;
-	case 21: r21 = val; MR_save_transient_registers(); return val;
-	case 22: r22 = val; MR_save_transient_registers(); return val;
-	case 23: r23 = val; MR_save_transient_registers(); return val;
-	case 24: r24 = val; MR_save_transient_registers(); return val;
-	case 25: r25 = val; MR_save_transient_registers(); return val;
-	case 26: r26 = val; MR_save_transient_registers(); return val;
-	case 27: r27 = val; MR_save_transient_registers(); return val;
-	case 28: r28 = val; MR_save_transient_registers(); return val;
-	case 29: r29 = val; MR_save_transient_registers(); return val;
-	case 30: r30 = val; MR_save_transient_registers(); return val;
-	case 31: r31 = val; MR_save_transient_registers(); return val;
-	case 32: r32 = val; MR_save_transient_registers(); return val;
+	case 1:  MR_r1  = val; MR_save_transient_registers(); return val;
+	case 2:  MR_r2  = val; MR_save_transient_registers(); return val;
+	case 3:  MR_r3  = val; MR_save_transient_registers(); return val;
+	case 4:  MR_r4  = val; MR_save_transient_registers(); return val;
+	case 5:  MR_r5  = val; MR_save_transient_registers(); return val;
+	case 6:  MR_r6  = val; MR_save_transient_registers(); return val;
+	case 7:  MR_r7  = val; MR_save_transient_registers(); return val;
+	case 8:  MR_r8  = val; MR_save_transient_registers(); return val;
+	case 9:  MR_r9  = val; MR_save_transient_registers(); return val;
+	case 10: MR_r10 = val; MR_save_transient_registers(); return val;
+	case 11: MR_r11 = val; MR_save_transient_registers(); return val;
+	case 12: MR_r12 = val; MR_save_transient_registers(); return val;
+	case 13: MR_r13 = val; MR_save_transient_registers(); return val;
+	case 14: MR_r14 = val; MR_save_transient_registers(); return val;
+	case 15: MR_r15 = val; MR_save_transient_registers(); return val;
+	case 16: MR_r16 = val; MR_save_transient_registers(); return val;
+	case 17: MR_r17 = val; MR_save_transient_registers(); return val;
+	case 18: MR_r18 = val; MR_save_transient_registers(); return val;
+	case 19: MR_r19 = val; MR_save_transient_registers(); return val;
+	case 20: MR_r20 = val; MR_save_transient_registers(); return val;
+	case 21: MR_r21 = val; MR_save_transient_registers(); return val;
+	case 22: MR_r22 = val; MR_save_transient_registers(); return val;
+	case 23: MR_r23 = val; MR_save_transient_registers(); return val;
+	case 24: MR_r24 = val; MR_save_transient_registers(); return val;
+	case 25: MR_r25 = val; MR_save_transient_registers(); return val;
+	case 26: MR_r26 = val; MR_save_transient_registers(); return val;
+	case 27: MR_r27 = val; MR_save_transient_registers(); return val;
+	case 28: MR_r28 = val; MR_save_transient_registers(); return val;
+	case 29: MR_r29 = val; MR_save_transient_registers(); return val;
+	case 30: MR_r30 = val; MR_save_transient_registers(); return val;
+	case 31: MR_r31 = val; MR_save_transient_registers(); return val;
+	case 32: MR_r32 = val; MR_save_transient_registers(); return val;
 
 	}
 
Index: mercury_tabling.c
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_tabling.c,v
retrieving revision 1.38
diff -u -b -r1.38 mercury_tabling.c
--- mercury_tabling.c	2001/01/13 09:23:25	1.38
+++ mercury_tabling.c	2001/01/13 09:34:00
@@ -1485,7 +1485,7 @@
 	MR_mkframe("mercury__table_builtin__table_nondet_suspend", 1,
 		MR_ENTRY(MR_do_fail));
 
-	table = (MR_TrieNode) r1;
+	table = (MR_TrieNode) MR_r1;
 	subgoal = table->MR_subgoal;
 	consumer = MR_table_allocate_bytes(sizeof(MR_Consumer));
 	consumer->remaining_answer_list_ptr = &subgoal->answer_list;
@@ -1661,7 +1661,7 @@
 	mercury__table_builtin__table_nondet_resume_1_0_RestartPoint,
 	mercury__table_builtin__table_nondet_resume_1_0);
 
-BEGIN_MODULE(table_nondet_resume_module)
+MR_BEGIN_MODULE(table_nondet_resume_module)
 	MR_init_entry_sl(mercury__table_builtin__table_nondet_resume_1_0);
 	MR_INIT_PROC_LAYOUT_ADDR(mercury__table_builtin__table_nondet_resume_1_0);
 	MR_init_label_sl(mercury__table_builtin__table_nondet_resume_1_0_ChangeLoop);
@@ -1671,7 +1671,7 @@
 	MR_init_label_sl(mercury__table_builtin__table_nondet_resume_1_0_ReturnAnswer);
 	MR_init_label_sl(mercury__table_builtin__table_nondet_resume_1_0_RedoPoint);
 	MR_init_label_sl(mercury__table_builtin__table_nondet_resume_1_0_RestartPoint);
-BEGIN_CODE
+MR_BEGIN_CODE
 
 MR_define_entry(mercury__table_builtin__table_nondet_resume_1_0);
 	MR_cur_leader = MR_top_generator_table();
@@ -1859,8 +1859,8 @@
 	** since will not have changed in the meantime.
 	*/
 
-	r1 = (MR_Word) &MR_cur_leader->resume_info->cur_consumer_answer_list->
-		answer_data;
+	MR_r1 = (MR_Word) &MR_cur_leader->resume_info->
+		cur_consumer_answer_list->answer_data;
 
 	MR_cur_leader->resume_info->cur_consumer->remaining_answer_list_ptr =
 		&(MR_cur_leader->resume_info->cur_consumer_answer_list->
@@ -1951,16 +1951,16 @@
 	(void) MR_pop_generator();
 
 	MR_proceed();
-END_MODULE
+MR_END_MODULE
 
 MR_define_extern_entry(MR_table_nondet_commit);
-BEGIN_MODULE(table_nondet_commit_module)
+MR_BEGIN_MODULE(table_nondet_commit_module)
 	MR_init_entry_ai(MR_table_nondet_commit);
-BEGIN_CODE
+MR_BEGIN_CODE
 MR_define_entry(MR_table_nondet_commit);
 	MR_commit_cut();
 	MR_fail();
-END_MODULE
+MR_END_MODULE
 
 #endif /* ! MR_HIGHLEVEL_CODE */
 
cvs diff: Diffing runtime/GETOPT
cvs diff: Diffing runtime/machdeps
cvs diff: Diffing samples
cvs diff: Diffing samples/c_interface
cvs diff: Diffing samples/c_interface/c_calls_mercury
cvs diff: Diffing samples/c_interface/cplusplus_calls_mercury
cvs diff: Diffing samples/c_interface/mercury_calls_c
cvs diff: Diffing samples/c_interface/mercury_calls_cplusplus
cvs diff: Diffing samples/c_interface/mercury_calls_fortran
cvs diff: Diffing samples/c_interface/simpler_c_calls_mercury
cvs diff: Diffing samples/c_interface/simpler_cplusplus_calls_mercury
cvs diff: Diffing samples/diff
cvs diff: Diffing samples/muz
cvs diff: Diffing samples/rot13
cvs diff: Diffing samples/solutions
cvs diff: Diffing samples/tests
cvs diff: Diffing samples/tests/c_interface
cvs diff: Diffing samples/tests/c_interface/c_calls_mercury
cvs diff: Diffing samples/tests/c_interface/cplusplus_calls_mercury
cvs diff: Diffing samples/tests/c_interface/mercury_calls_c
cvs diff: Diffing samples/tests/c_interface/mercury_calls_cplusplus
cvs diff: Diffing samples/tests/c_interface/mercury_calls_fortran
cvs diff: Diffing samples/tests/c_interface/simpler_c_calls_mercury
cvs diff: Diffing samples/tests/c_interface/simpler_cplusplus_calls_mercury
cvs diff: Diffing samples/tests/diff
cvs diff: Diffing samples/tests/muz
cvs diff: Diffing samples/tests/rot13
cvs diff: Diffing samples/tests/solutions
cvs diff: Diffing samples/tests/toplevel
cvs diff: Diffing scripts
cvs diff: Diffing tests
cvs diff: Diffing tests/benchmarks
cvs diff: Diffing tests/debugger
cvs diff: Diffing tests/debugger/declarative
cvs diff: Diffing tests/dppd
cvs diff: Diffing tests/general
cvs diff: Diffing tests/general/accumulator
cvs diff: Diffing tests/hard_coded
cvs diff: Diffing tests/hard_coded/exceptions
cvs diff: Diffing tests/hard_coded/purity
cvs diff: Diffing tests/hard_coded/sub-modules
cvs diff: Diffing tests/hard_coded/typeclasses
cvs diff: Diffing tests/invalid
cvs diff: Diffing tests/invalid/purity
cvs diff: Diffing tests/misc_tests
cvs diff: Diffing tests/tabling
cvs diff: Diffing tests/term
cvs diff: Diffing tests/valid
cvs diff: Diffing tests/warnings
cvs diff: Diffing tools
cvs diff: Diffing trace
Index: trace/mercury_trace.c
===================================================================
RCS file: /home/mercury1/repository/mercury/trace/mercury_trace.c,v
retrieving revision 1.35
diff -u -b -r1.35 mercury_trace.c
--- trace/mercury_trace.c	2000/12/20 07:44:57	1.35
+++ trace/mercury_trace.c	2001/01/13 02:03:27
@@ -1127,7 +1127,7 @@
 		}
 
 		if (proc_layout->MR_sle_maybe_call_table <= 0) {
-			fatal_error("minimal model procedure "
+			MR_fatal_error("minimal model procedure "
 					"has no call table slot");
 		}
 
cvs diff: Diffing trial
cvs diff: Diffing util
--------------------------------------------------------------------------
mercury-developers mailing list
Post messages to:       mercury-developers at cs.mu.oz.au
Administrative Queries: owner-mercury-developers at cs.mu.oz.au
Subscriptions:          mercury-developers-request at cs.mu.oz.au
--------------------------------------------------------------------------



More information about the developers mailing list
Index: library/exception.m
===================================================================
RCS file: /home/mercury1/repository/mercury/library/exception.m,v
retrieving revision 1.39
diff -u -b -r1.39 exception.m
--- library/exception.m	2001/01/10 08:57:54	1.39
+++ library/exception.m	2001/01/13 07:21:41
@@ -1202,9 +1202,9 @@
 **	if throws an exception, call Handler(Exception, Result).
 **
 ** This is the model_det version.
 ** On entry, we have a type_info (which we don't use) in r1,
 ** the Goal to execute in r2 and the Handler in r3.
 ** On exit, we should put Result in r1.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_0); /* det */
 #ifdef PROFILE_CALLS
@@ -1216,17 +1216,17 @@
 MR_define_entry(mercury__exception__builtin_catch_3_2); /* cc_multi */
 	/*
 	** Create an exception handler entry on the nondet stack.
 	** (Register r3 holds the Handler closure.)
 	*/
 	MR_create_exception_handler(""builtin_catch/3 [model_det]"",
-		MR_MODEL_DET_HANDLER, r3, MR_ENTRY(MR_do_fail));
+		MR_MODEL_DET_HANDLER, MR_r3, MR_ENTRY(MR_do_fail));
 	
 	/*
 	** Now call `Goal(Result)'.
 	*/
-	r1 = r2;	/* The Goal to call */
-	r2 = 0;		/* Zero additional input arguments */
-	r3 = 1;		/* One output argument */
+	MR_r1 = MR_r2;	/* The Goal to call */
+	MR_r2 = 0;		/* Zero additional input arguments */
+	MR_r3 = 1;		/* One output argument */
 	MR_call(MR_ENTRY(mercury__do_call_closure), 
 		MR_LABEL(mercury__exception__builtin_catch_3_2_i2),
 		MR_ENTRY(mercury__exception__builtin_catch_3_2));
@@ -1235,7 +1235,7 @@
 	MR_update_prof_current_proc(
 		MR_LABEL(mercury__exception__builtin_catch_3_2));
 	/*
 	** On exit from mercury__do_call_closure, Result is in r1
 	**
 	** We must now deallocate the ticket and nondet stack frame that
 	** were allocated by MR_create_exception_handler().
@@ -1253,9 +1253,9 @@
 **	if throws an exception, call Handler(Exception, Result).
 **
 ** This is the model_semi version.
 ** On entry, we have a type_info (which we don't use) in r1,
 ** the Goal to execute in r2 and the Handler in r3,
 ** and on exit, we should put Result in r2.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_1); /* semidet */
 #ifdef PROFILE_CALLS
@@ -1267,17 +1267,17 @@
 MR_define_entry(mercury__exception__builtin_catch_3_3); /* cc_nondet */
 	/*
 	** Create an exception handler entry on the nondet stack.
 	** (Register r3 holds the Handler closure.)
 	*/
 	MR_create_exception_handler(""builtin_catch/3 [model_semi]"",
-		MR_MODEL_SEMI_HANDLER, r3, MR_ENTRY(MR_do_fail));
+		MR_MODEL_SEMI_HANDLER, MR_r3, MR_ENTRY(MR_do_fail));
 	
 	/*
 	** Now call `Goal(Result)'.
 	*/
-	r1 = r2;	/* The Goal to call */
-	r2 = 0;		/* Zero additional input arguments */
-	r3 = 1;		/* One output argument */
+	MR_r1 = MR_r2;	/* The Goal to call */
+	MR_r2 = 0;	/* Zero additional input arguments */
+	MR_r3 = 1;	/* One output argument */
 	MR_call(MR_ENTRY(mercury__do_call_closure), 
 		MR_LABEL(mercury__exception__builtin_catch_3_3_i2),
 		MR_ENTRY(mercury__exception__builtin_catch_3_3));
@@ -1287,13 +1287,13 @@
 		MR_LABEL(mercury__exception__builtin_catch_3_3));
 	/*
 	** On exit from do_call_semidet_closure, the success/failure
 	** indicator is in r1, and Result is in r2.
 	** Note that we call succeed_discard() to exit regardless
 	** of whether r1 is true or false.  We just return the r1 value
 	** back to our caller.
 	*/
 #ifdef MR_USE_TRAIL
-	if (r1) {
+	if (MR_r1) {
 		MR_prune_ticket();
 	} else {
 		MR_discard_ticket();
@@ -1309,9 +1309,9 @@
 **	if throws an exception, call Handler(Exception, Result).
 **
 ** This is the model_non version.
 ** On entry, we have a type_info (which we don't use) in r1,
 ** the Goal to execute in r2 and the Handler in r3.
 ** On exit, we should put Result in r1.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_4); /* multi */
 #ifdef PROFILE_CALLS
@@ -1323,24 +1323,24 @@
 MR_define_entry(mercury__exception__builtin_catch_3_5); /* nondet */
 	/*
 	** Create an exception handler entry on the nondet stack.
 	** (Register r3 holds the Handler closure.)
 	*/
 #ifdef MR_USE_TRAIL
 	MR_create_exception_handler(""builtin_catch/3 [model_nondet]"",
-		MR_MODEL_NON_HANDLER, r3,
+		MR_MODEL_NON_HANDLER, MR_r3,
 		MR_LABEL(mercury__exception__builtin_catch_3_5_i3));
 #else
 	MR_create_exception_handler(""builtin_catch/3 [model_nondet]"",
-		MR_MODEL_NON_HANDLER, r3, MR_ENTRY(MR_do_fail));
+		MR_MODEL_NON_HANDLER, MR_r3, MR_ENTRY(MR_do_fail));
 #endif
 	
 
 	/*
 	** Now call `Goal(Result)'.
 	*/
-	r1 = r2;	/* the Goal to call */
-	r2 = 0;		/* Zero additional input arguments */
-	r3 = 1;		/* One output argument */
+	MR_r1 = MR_r2;	/* the Goal to call */
+	MR_r2 = 0;	/* Zero additional input arguments */
+	MR_r3 = 1;	/* One output argument */
 	MR_call(MR_ENTRY(mercury__do_call_closure), 
 		MR_LABEL(mercury__exception__builtin_catch_3_5_i2),
 		MR_ENTRY(mercury__exception__builtin_catch_3_5));
@@ -1349,7 +1349,7 @@
 	MR_update_prof_current_proc(
 		MR_LABEL(mercury__exception__builtin_catch_3_5));
 	/*
 	** On exit from do_call_nondet_closure, Result is in r1
 	**
 	** Note that we need to keep the trail ticket still,
 	** in case it is needed again on backtracking.
@@ -1373,11 +1373,11 @@
 **	The longjmp() will branch to builtin_catch which will then
 **	call Handler(Exception, Result).
 **
 ** On entry, we have Exception in r1.
 */
 MR_define_entry(mercury__exception__builtin_throw_1_0);
 {
-	MR_Word exception = r1;
+	MR_Word exception = MR_r1;
 	MR_Word handler;
 	enum MR_HandlerCodeModel catch_code_model;
 	MR_Word *orig_curfr;
@@ -1427,8 +1427,8 @@
 			** We also need to save & restore the MR_succip
 			** across that call, since any call to Mercury code
 			** may clobber MR_succip (and also the Mercury
 			** registers r1, r2, r3, etc., but for those we don't
 			** care, since we don't use them).
 			** Note that the MR_save_registers() alone is not
 			** sufficient since the Mercury code may clobber the
 			** copy of MR_succip in the fake_reg.
@@ -1600,16 +1600,16 @@
 	** Otherwise, the handler is a Mercury closure.
 	** Invoke the handler as `Handler(Exception, Result)'.
 	*/
-	r1 = handler;		/* get the Handler closure */
-	r2 = 1;			/* One additional input argument */
-	r3 = 1;			/* One output argument */
-	r4 = exception;		/* This is our one input argument */
+	MR_r1 = handler;	/* get the Handler closure */
+	MR_r2 = 1;		/* One additional input argument */
+	MR_r3 = 1;		/* One output argument */
+	MR_r4 = exception;	/* This is our one input argument */
 
 	/*
 	** If the catch was semidet, we need to set the success indicator
 	** r1 to TRUE and return the result in r2; otherwise, we return
 	** the result in r1, which is where mercury__do_call_closure puts it,
 	** so we can do a tailcall.
 	*/
 	if (catch_code_model != MR_MODEL_SEMI_HANDLER) {
 		MR_tailcall(MR_ENTRY(mercury__do_call_closure), 
@@ -1625,8 +1625,8 @@
 	MR_update_prof_current_proc(
 		MR_LABEL(mercury__exception__builtin_throw_1_0));
 	/* we've just returned from mercury__do_call_closure */
-	r2 = r1;
-	r1 = TRUE;
+	MR_r2 = MR_r1;
+	MR_r1 = TRUE;
 	MR_succip = (MR_Code *) MR_stackvar(1);
 	MR_decr_sp_pop_msg(1);
 	MR_proceed(); /* return to the caller of `builtin_catch' */
@@ -1202,9 +1202,9 @@
 **
 ** This is the model_det version.
-** On entry, we have a type_info (which we don't use) in r1,
-** the Goal to execute in r2 and the Handler in r3.
-** On exit, we should put Result in r1.
+** On entry, we have a type_info (which we don't use) in MR_r1,
+** the Goal to execute in MR_r2 and the Handler in MR_r3.
+** On exit, we should put Result in MR_r1.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_0); /* det */
@@ -1216,17 +1216,17 @@
 	/*
 	** Create an exception handler entry on the nondet stack.
-	** (Register r3 holds the Handler closure.)
+	** (Register MR_r3 holds the Handler closure.)
 	*/
 	MR_create_exception_handler(""builtin_catch/3 [model_det]"",
@@ -1235,7 +1235,7 @@
 		MR_LABEL(mercury__exception__builtin_catch_3_2));
 	/*
-	** On exit from mercury__do_call_closure, Result is in r1
+	** On exit from mercury__do_call_closure, Result is in MR_r1
 	**
 	** We must now deallocate the ticket and nondet stack frame that
@@ -1253,9 +1253,9 @@
 **
 ** This is the model_semi version.
-** On entry, we have a type_info (which we don't use) in r1,
-** the Goal to execute in r2 and the Handler in r3,
-** and on exit, we should put Result in r2.
+** On entry, we have a type_info (which we don't use) in MR_r1,
+** the Goal to execute in MR_r2 and the Handler in MR_r3,
+** and on exit, we should put Result in MR_r2.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_1); /* semidet */
@@ -1267,17 +1267,17 @@
 	/*
 	** Create an exception handler entry on the nondet stack.
-	** (Register r3 holds the Handler closure.)
+	** (Register MR_r3 holds the Handler closure.)
 	*/
 	MR_create_exception_handler(""builtin_catch/3 [model_semi]"",
@@ -1287,13 +1287,13 @@
 	/*
 	** On exit from do_call_semidet_closure, the success/failure
-	** indicator is in r1, and Result is in r2.
+	** indicator is in MR_r1, and Result is in MR_r2.
 	** Note that we call succeed_discard() to exit regardless
@@ -1287,13 +1287,13 @@
 	** Note that we call succeed_discard() to exit regardless
-	** of whether r1 is true or false.  We just return the r1 value
+	** of whether MR_r1 is true or false.  We just return the MR_r1 value
 	** back to our caller.
 	*/
@@ -1309,9 +1309,9 @@
 **
 ** This is the model_non version.
-** On entry, we have a type_info (which we don't use) in r1,
-** the Goal to execute in r2 and the Handler in r3.
-** On exit, we should put Result in r1.
+** On entry, we have a type_info (which we don't use) in MR_r1,
+** the Goal to execute in MR_r2 and the Handler in MR_r3.
+** On exit, we should put Result in MR_r1.
 */
 MR_define_entry(mercury__exception__builtin_catch_3_4); /* multi */
@@ -1323,24 +1323,24 @@
 	/*
 	** Create an exception handler entry on the nondet stack.
-	** (Register r3 holds the Handler closure.)
+	** (Register MR_r3 holds the Handler closure.)
 	*/
 #ifdef MR_USE_TRAIL
@@ -1349,7 +1349,7 @@
 		MR_LABEL(mercury__exception__builtin_catch_3_5));
 	/*
-	** On exit from do_call_nondet_closure, Result is in r1
+	** On exit from do_call_nondet_closure, Result is in MR_r1
 	**
 	** Note that we need to keep the trail ticket still,
@@ -1373,11 +1373,11 @@
 **	call Handler(Exception, Result).
 **
-** On entry, we have Exception in r1.
+** On entry, we have Exception in MR_r1.
 */
 MR_define_entry(mercury__exception__builtin_throw_1_0);
@@ -1427,8 +1427,8 @@
 			** across that call, since any call to Mercury code
 			** may clobber MR_succip (and also the Mercury
-			** registers r1, r2, r3, etc., but for those we don't
-			** care, since we don't use them).
+			** registers MR_r1, MR_r2, MR_r3, etc., but for those
+			** we don't care, since we don't use them).
 			** Note that the MR_save_registers() alone is not
 			** sufficient since the Mercury code may clobber the
@@ -1600,16 +1600,16 @@
 	/*
 	** If the catch was semidet, we need to set the success indicator
-	** r1 to TRUE and return the result in r2; otherwise, we return
-	** the result in r1, which is where mercury__do_call_closure puts it,
-	** so we can do a tailcall.
+	** MR_r1 to TRUE and return the result in MR_r2; otherwise, we return
+	** the result in MR_r1, which is where mercury__do_call_closure puts
+	** it, so we can do a tailcall.
 	*/
 	if (catch_code_model != MR_MODEL_SEMI_HANDLER) {
Index: runtime/mercury_ho_call.c
===================================================================
RCS file: /home/mercury1/repository/mercury/runtime/mercury_ho_call.c,v
retrieving revision 1.42
diff -u -b -r1.42 mercury_ho_call.c
--- runtime/mercury_ho_call.c	2000/12/04 18:35:05	1.42
+++ runtime/mercury_ho_call.c	2001/01/12 15:05:33
@@ -31,31 +31,32 @@
 ** provided by the higher-order call may be input or output, and may appear
 ** in any order.
 **
 ** The input arguments to do_call_*_closure are the closure in r1,
 ** the number of additional input arguments in r2, the number of output
 ** arguments to expect in r3, and the additional input arguments themselves
 ** in r4, r5, etc. The output arguments are returned in registers r1, r2, etc
 ** for det and nondet calls or registers r2, r3, etc for semidet calls.
 **
-** The placement of the extra input arguments into r4, r5 etc is done by
+** The placement of the extra input arguments into MR_r4, MR_r5 etc is done by
 ** the code generator, as is the movement of the output arguments to their
 ** eventual destinations.
 */
 
 	/*
 	** Number of input arguments to do_call_*_closure,
 	** r1 -> closure
 	** r2 -> number of immediate input arguments.
 	** r3 -> number of output arguments (unused).
 	*/
 #define MR_HO_CALL_INPUTS		3
 
 	/*
 	** Number of input arguments to do_call_*_class_method,
 	** r1 -> typeclass info
 	** r2 -> index of method in typeclass info
 	** r3 -> number of immediate input arguments.
 	** r4 -> number of output arguments (unused).
 	*/
 #define MR_CLASS_METHOD_CALL_INPUTS	4
 
@@ -100,8 +101,8 @@
 	int		num_hidden_args;/* # of args hidden in the closure  */
 	int		i;
 
-	closure = (MR_Closure *) r1;
-	num_extra_args = r2;
+	closure = (MR_Closure *) MR_r1;
+	num_extra_args = MR_r2;
 	num_hidden_args = closure->MR_closure_num_hidden_args;
 
 	MR_save_registers();
@@ -128,18 +129,18 @@
 
 	/*
 	** Note that we pass MR_prof_ho_caller_proc rather than
-	** MR_LABEL(MR_do_call_closure), so that the call gets recorded
+	** MR_LABEL(mercury__do_call_closure), so that the call gets recorded
 	** as having come from our caller.
 	*/
 	MR_tailcall(closure->MR_closure_code, MR_prof_ho_caller_proc);
 }
 
 	/*
 	** r1: the typeclass_info
 	** r2: index of class method
 	** r3: number of immediate input arguments
 	** r4: number of output arguments
 	** r5+:input args
 	*/
 
 /*
@@ -155,11 +156,11 @@
 	int	num_extra_instance_args;
 	int	i;
 
-	destination = MR_typeclass_info_class_method(r1, r2);
+	destination = MR_typeclass_info_class_method(MR_r1, MR_r2);
 	num_extra_instance_args = 
-		(int) MR_typeclass_info_num_extra_instance_args(r1);
+		(int) MR_typeclass_info_num_extra_instance_args(MR_r1);
 
-	num_in_args = r3; /* number of input args */
+	num_in_args = MR_r3; /* number of input args */
 
 	MR_save_registers();
 
@@ -189,8 +190,8 @@
 
 	/*
 	** Note that we pass MR_prof_ho_caller_proc rather than
-	** MR_LABEL(MR_do_call_class_method), so that the call gets recorded
-	** as having come from our caller.
+	** MR_LABEL(mercury__do_call_class_method), so that the call gets
+	** recorded as having come from our caller.
 	*/
 	MR_tailcall(destination, MR_prof_ho_caller_proc);
 }
@@ -211,15 +212,15 @@
 
 #define initialize()							\
 	do {								\
-		type_info = (MR_TypeInfo) r1;				\
-		x = r2;							\
-		y = r3;							\
+		type_info = (MR_TypeInfo) MR_r1;			\
+		x = MR_r2;						\
+		y = MR_r3;						\
 		saved_succip = MR_succip;				\
 	} while(0)
 
 #define return_answer(answer)						\
 	do {								\
-		r1 = (answer);						\
+		MR_r1 = (answer);					\
 		MR_succip = saved_succip;				\
 		MR_proceed();						\
 	} while(0)
@@ -281,15 +282,15 @@
 
 #define initialize()							\
 	do {								\
-		type_info = (MR_TypeInfo) r1;				\
-		x = r2;							\
-		y = r3;							\
+		type_info = (MR_TypeInfo) MR_r1;			\
+		x = MR_r2;						\
+		y = MR_r3;						\
 		saved_succip = MR_succip;				\
 	} while(0)
 
 #define return_answer(answer)						\
 	do {								\
-		r1 = (answer);						\
+		MR_r1 = (answer);					\
 		MR_succip = saved_succip;				\
 		MR_proceed();						\
 	} while(0)
@@ -339,7 +340,7 @@
 		MR_save_transient_registers();				\
 		(void) MR_call_engine(type_ctor_info->unify_pred, FALSE);\
 		MR_restore_transient_registers();			\
-		return (r1);						\
+		return (MR_r1);						\
 	} while (0)
 
 #define	start_label		unify_func_start
@@ -379,7 +380,7 @@
 		MR_save_transient_registers();				\
 		(void) MR_call_engine(type_ctor_info->compare_pred, FALSE);\
 		MR_restore_transient_registers();			\
-		return (r1);						\
+		return (MR_r1);						\
 	} while (0)
 
 #define	start_label		compare_func_start
@@ -31,31 +31,32 @@
 ** in any order.
 **
-** The input arguments to do_call_*_closure are the closure in r1,
-** the number of additional input arguments in r2, the number of output
-** arguments to expect in r3, and the additional input arguments themselves
-** in r4, r5, etc. The output arguments are returned in registers r1, r2, etc
-** for det and nondet calls or registers r2, r3, etc for semidet calls.
+** The input arguments to do_call_*_closure are the closure in MR_r1,
+** the number of additional input arguments in MR_r2, the number of output
+** arguments to expect in MR_r3, and the additional input arguments themselves
+** in MR_r4, MR_r5, etc. The output arguments are returned in registers MR_r1,
+** MR_r2, etc for det and nondet calls or registers MR_r2, MR_r3, etc for
+** semidet calls.
 **
@@ -31,31 +31,32 @@
 	/*
 	** Number of input arguments to do_call_*_closure,
-	** r1 -> closure
-	** r2 -> number of immediate input arguments.
-	** r3 -> number of output arguments (unused).
+	** MR_r1 -> closure
+	** MR_r2 -> number of immediate input arguments.
+	** MR_r3 -> number of output arguments (unused).
 	*/
 #define MR_HO_CALL_INPUTS		3
@@ -31,31 +31,32 @@
 	/*
 	** Number of input arguments to do_call_*_class_method,
-	** r1 -> typeclass info
-	** r2 -> index of method in typeclass info
-	** r3 -> number of immediate input arguments.
-	** r4 -> number of output arguments (unused).
+	** MR_r1 -> typeclass info
+	** MR_r2 -> index of method in typeclass info
+	** MR_r3 -> number of immediate input arguments.
+	** MR_r4 -> number of output arguments (unused).
 	*/
 #define MR_CLASS_METHOD_CALL_INPUTS	4
@@ -128,18 +129,18 @@
 
 	/*
-	** r1: the typeclass_info
-	** r2: index of class method
-	** r3: number of immediate input arguments
-	** r4: number of output arguments
-	** r5+:input args
+	** MR_r1: the typeclass_info
+	** MR_r2: index of class method
+	** MR_r3: number of immediate input arguments
+	** MR_r4: number of output arguments
+	** MR_r5+:input args
 	*/
 